@@ -320,4 +320,11 @@ impl FuturesAccount {
             .delete_signed::<Empty>(API::Futures(Futures::AllOpenOrders), Some(request))
             .map(|_| ())
     }
+
+    pub fn get_all_open_orders<S>(&self, symbol: S) -> Result<Vec<crate::futures::model::Order>> where S: Into<String> {
+        let mut parameters: BTreeMap<String, String> = BTreeMap::new();
+        parameters.insert("symbol".into(), symbol.into());
+        let request = build_signed_request(parameters, self.recv_window)?;
+        self.client.get_signed(API::Futures(Futures::OpenOrders), Some(request))
+    }
 }
\ No newline at end of file
